#!/usr/bin/env python3
"""
Subnet Scanner
Parameters:
    - IP: Network IP address (e.g., 192.168.1.0)
    - port: Port to scan on each host
"""
import ipaddress
import socket
import concurrent.futures
import argparse

def scan_host(ip, port):
    try:
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.settimeout(1)
        result = sock.connect_ex((str(ip), port))
        if result == 0:
            print(f"Host {ip} is up and port {port} is open")
        sock.close()
    except:
        pass

def scan_subnet(network, port):
    try:
        net = ipaddress.ip_network(network)
        print(f"Scanning subnet {net}...")
        
        with concurrent.futures.ThreadPoolExecutor(max_workers=50) as executor:
            futures = [executor.submit(scan_host, ip, port) for ip in net.hosts()]
            concurrent.futures.wait(futures)
            
    except Exception as e:
        print(f"Error: {str(e)}")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Subnet Scanner")
    parser.add_argument("network", help="Network address (e.g., 192.168.1.0/24)")
    parser.add_argument("port", type=int, help="Port to scan")
    args = parser.parse_args()
    
    scan_subnet(args.network, args.port)
